#include <BlacklistInterface.h>

static char *blacklist_cli_show(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
{
	switch (cmd) {
		case CLI_INIT:
			e->command = "kerio blacklist show";
			e->usage = "Usage: kerio blacklist show\n"
				"	Print blacklist\n";
			return NULL;
		case CLI_GENERATE:
			return NULL;
		default:
			if (a->argc != e->args) {
				return CLI_SHOWUSAGE;
			}
	}

	blacklist_print(a->fd);
	return CLI_SUCCESS;
}

static char *blacklist_cli_test(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
{
	switch (cmd) {
		case CLI_INIT:
			e->command = "kerio blacklist test";
			e->usage = "Usage: kerio blacklist test <number>\n"
				"	Test number agains the blacklist\n";
			return NULL;
		case CLI_GENERATE:
			return NULL;
		default:
			if (a->argc != e->args + 1) {
				return CLI_SHOWUSAGE;
			}
	}

	ast_cli(a->fd, "Testing number \"%s\": ", a->argv[3]);
	if (blacklist_match(a->argv[3])) {
		ast_cli(a->fd, "found\n");
	}
	else {
		ast_cli(a->fd, "not found\n");
	}

	return CLI_SUCCESS;
}

/**
 * find number in the blacklist
 */
static int blacklist_func_match_read(struct ast_channel *chan, const char *cmd, char *data, char *buf, size_t len)
{
	int result;
	AST_DECLARE_APP_ARGS(args,
		AST_APP_ARG(extensionNumber);
		);

	if (ast_strlen_zero(data)) {
		/* empty argument - anonymous caller (e.g. HW cards) */
		result = blacklist_match("");
	}
	else {
		AST_STANDARD_APP_ARGS(args, data);

		if (args.argc != 1) {
			ast_log(AST_LOG_WARNING, "Syntax: KERIO_BLACKLIST_MATCH(number) - invalid arguments!\n");
			return -1;
		}
		result = blacklist_match(args.extensionNumber);
	}

	switch (result) {
		case 0: //miss
			ast_verb(3, "Blacklist match ... [FALSE]\n");
			snprintf(buf, len, "%d", 0);
			break;
		case 1: //hit
			ast_verb(3, "Blacklist match ... [TRUE]\n");
			snprintf(buf, len, "%d", 1);
			break;
	}

	return 0;
}

static struct ast_custom_function blaclikst_func_match = {
	.name = "KERIO_BLACKLIST_MATCH",
	.desc = "Check number in the blacklist",
	.syntax = "KERIO_BLACKLIST_MATCH(number)",
	.read = blacklist_func_match_read,
};

static struct ast_cli_entry blacklist_cli[] = {
	AST_CLI_DEFINE(blacklist_cli_show, "Print blacklist"),
	AST_CLI_DEFINE(blacklist_cli_test, "Test blacklist"),
};

static int load_module_blacklist(void)
{
	blacklist_load();

	ast_cli_register_multiple(blacklist_cli, ARRAY_LEN(blacklist_cli));
	ast_custom_function_register(&blaclikst_func_match);

	return AST_MODULE_LOAD_SUCCESS;
}

static int unload_module_blacklist(void)
{
	ast_cli_unregister_multiple(blacklist_cli, ARRAY_LEN(blacklist_cli));
	ast_custom_function_unregister(&blaclikst_func_match);

	blacklist_unload();

	return 0;
}

static int reload_module_blacklist(void)
{
	blacklist_unload();
	blacklist_load();

	return 0;
}
