#include <DialplanInterface.h>

static char *dialplan_cli_show(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
{
	switch (cmd) {
		case CLI_INIT:
			e->command = "kerio dialplan show";
			e->usage = "Usage: kerio dialplan show\n"
				"	Print loaded extensions\n";
			return NULL;
		case CLI_GENERATE:
			return NULL;
		default:
			if (a->argc != e->args) {
				return CLI_SHOWUSAGE;
			}
	}

	dialplan_printExtensions(a->fd);
	return CLI_SUCCESS;
}

/**
 * find extension in the dialplan
 */
static int dialplan_func_find_read(struct ast_channel *chan, const char *cmd, char *data, char *buf, size_t len)
{
	AST_DECLARE_APP_ARGS(args,
		AST_APP_ARG(extensionNumber);
		AST_APP_ARG(usageFlag);
		);

	if (ast_strlen_zero(data)) {
		ast_log(AST_LOG_WARNING, "Syntax: KERIO_DIALPLAN_FIND(extensionNumber,usageFlag) - missing arguments!\n");
		return -1;
	}

	AST_STANDARD_APP_ARGS(args, data);

	if (args.argc != 2) {
		ast_log(AST_LOG_WARNING, "Syntax: KERIO_DIALPLAN_FIND(extensionNumber,usageFlag) - missing arguments!\n");
		return -1;
	}

	if (0 == strcmp(args.usageFlag, "dialByExt")) {
		switch (dialplan_findExt(args.extensionNumber)) {
			case 0: //miss
				ast_verb(3, "Dialplan find %s... [FALSE]\n", args.extensionNumber);
				snprintf(buf, len, "%d", 0);
				break;
			case 1: //hit
				ast_verb(3, "Dialplan find %s... [TRUE]\n", args.extensionNumber);
				snprintf(buf, len, "%d", 1);
				break;
		}
		return 0;
	}
	ast_log(AST_LOG_WARNING, "Syntax: KERIO_DIALPLAN_FIND(extensionNumber,usageFlag) - invalid usage flag!\n");
	return -1;
}

static struct ast_custom_function dialplan_func_find = {
	.name = "KERIO_DIALPLAN_FIND",
	.desc = "Check if extension exists in the dialplan",
	.syntax = "KERIO_DIALPLAN_FIND(extensionNumber,usageFlag)",
	.read = dialplan_func_find_read,
};

static struct ast_cli_entry dialplan_cli[] = {
	AST_CLI_DEFINE(dialplan_cli_show, "Print loaded extensions"),
};

static int load_module_dialplan(void)
{
	dialplan_load();

	ast_cli_register_multiple(dialplan_cli, ARRAY_LEN(dialplan_cli));
	ast_custom_function_register(&dialplan_func_find);

	return AST_MODULE_LOAD_SUCCESS;
}

static int unload_module_dialplan(void)
{
	ast_cli_unregister_multiple(dialplan_cli, ARRAY_LEN(dialplan_cli));
	ast_custom_function_unregister(&dialplan_func_find);

	dialplan_unload();

	return 0;
}

static int reload_module_dialplan(void)
{
	dialplan_unload();
	dialplan_load();

	return 0;
}
