#include <CallHistoryInterface.h>

static char *history_appName = "KerioSet";
static char *history_appSynopsis = "Smarter version of set";
static char *history_appDescription =
	"Usage: KerioSet([ktsFrom=[val]],[ktsTo=[val]],[ktsStatus=[val]],[ktsFromType=[val]],[ktsToType=[val]])\n"
	"Updates cdr channel variables ktsXXX and ktsXXXInit, where ktsXXXInit is changed only on the first call.\n"
	"Sends a CEL event."
	"Example: KerioSet(ktsFrom=9777)\n"
	"  1. Sets ktsFrom=9777\n"
	"  2. Sets ktsFromInit=9777\n"
	"  3. If called again, only the ktsFrom is set. ktsFromInit is left intact.\n";

static int history_app_update(struct ast_channel *chan, const char *data)
{
	history_update(chan, data);
	return 0;
}

static struct ast_manager_event_blob *history_to_ami(struct stasis_message *message)
{
	struct ast_json_payload *payload = stasis_message_data(message);
	struct ast_manager_event_blob *res = NULL;

	struct ast_json *fromNum = ast_json_object_get(payload->json, "fromNum");
	struct ast_json *toNum = ast_json_object_get(payload->json, "toNum");

	res = ast_manager_event_blob_create(EVENT_FLAG_SYSTEM, "KerioHistoryUpdate",
		"FromNum: %s\r\n"
		"ToNum: %s\r\n",
		ast_json_string_get(fromNum),
		ast_json_string_get(toNum));
	return res;
}

STASIS_MESSAGE_TYPE_DEFN(history_msg_type,
	.to_ami = history_to_ami,
	);

static int load_module_history(void)
{
	STASIS_MESSAGE_TYPE_INIT(history_msg_type);

	history_load();

	ast_register_application(history_appName, history_app_update, history_appSynopsis, history_appDescription);
	ast_cdr_register("kerio_history", "Kerio CDR Backend", history_log);

	return AST_MODULE_LOAD_SUCCESS;
}

static int unload_module_history(void)
{
	ast_cdr_unregister("kerio_history");
	ast_unregister_application(history_appName);

	history_unload();

	STASIS_MESSAGE_TYPE_CLEANUP(history_msg_type);

	return 0;
}

static int reload_module_history(void)
{
	history_unload();
	history_load();

	return 0;
}
