#include "Interface.h"
#include "ActiveCalls.h"
#include "ActiveCallsInterface.h"

static ActiveCalls *activeCalls;
static Lock loadLock;

int activecalls_load()
{
	LockUnique l(&loadLock.l);
	if (!l.ok) return 0;

	activeCalls = new ActiveCalls();
	return 0;
}

void activecalls_unload()
{
	LockUnique l(&loadLock.l);

	if (activeCalls) {
		delete activeCalls;
		activeCalls = NULL;
	}
}

void activecalls_reload()
{
	LockUnique l(&loadLock.l);
	if (!l.ok) return;

	/* do not unregister cel */
	/* do not reload the module - active calls would be lost */

	if (activeCalls) {
		activeCalls->reload();
	}
}

void activecalls_cel(struct ast_event *event)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return;
	}

	activeCalls->cel(event);
}

void activecalls_print(const int fd)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return;
	}

	activeCalls->print(fd);
}

int activecalls_getCountPrefix(int scope, std::vector<std::string> &prefixes)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return 0;
	}

	return activeCalls->getCallsCountPrefix(scope, prefixes);
}

int activecalls_getDurationPrefix(int scope, std::vector<std::string> &prefixes)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return 0;
	}

	return activeCalls->getCallsDurationPrefix(scope, prefixes);
}

int activecalls_hangupOutgoingCalls(std::vector<std::string> emergencyList, std::vector<std::string> routePrefixes)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return 0;
	}

	return activeCalls->hangupOutgoingCalls(emergencyList, routePrefixes);
}

KTS_ExtensionType activecalls_getExtensionTypeConf(const std::string &telNum)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return KTS_ExtensionTypeUnknown;
	}

	return activeCalls->getExtensionTypeConf(telNum);
}

KTS_ExtensionType activecalls_getExtensionType(const std::string &telNum)
{
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return KTS_ExtensionTypeUnknown;
	}

	return activeCalls->getExtensionType(telNum);
}

int activecalls_amiSendCallsCb(const void *arg) {
	LockShared l(&loadLock.l);
	if (!activeCalls) {
		return 0;
	}

	activeCalls->amiSendCalls();

	return 0;
}