#include "Interface.h"
#include "CallHistory.h"
#include "CallHistoryInterface.h"

static CallHistory *callHistory;
static Lock loadLock;

int history_load()
{
	LockUnique l(&loadLock.l);
	if (!l.ok) return 0;

	callHistory = new CallHistory();
	return 0;
}

void history_unload()
{
	LockUnique l(&loadLock.l);
	if (!l.ok) return;

	if (callHistory) {
		delete callHistory;
		callHistory = NULL;
	}
}

int history_log(struct ast_cdr *cdr)
{
	LockShared l(&loadLock.l);
	if (!callHistory) {
		return 0;
	}
	return callHistory->cdrLog(cdr);
}

void history_update(struct ast_channel *chan, const char *arg)
{
	LockShared l(&loadLock.l);
	if (!callHistory) {
		return;
	}
	callHistory->asteriskUpdateParams(chan, arg);
}

int history_getCountPrefix(int scope, std::vector<std::string> prefixes, int timeframe)
{
	LockShared l(&loadLock.l);
	if (!callHistory) {
		return 0;
	}

	return callHistory->getCallsCountPrefix(scope, prefixes, timeframe);
}

int history_getDurationPrefix(int scope, std::vector<std::string> prefixes, int timeframe)
{
	LockShared l(&loadLock.l);
	if (!callHistory) {
		return 0;
	}

	return callHistory->getCallsDurationPrefix(scope, prefixes, timeframe);
}

