#include "Dialplan.h"

DialPlan::DialPlan()
{
	try {
		boost::property_tree::ptree pt;
		boost::property_tree::json_parser::read_json("/etc/asterisk/kerio_dialplan.conf", pt);

		BOOST_FOREACH(boost::property_tree::ptree::value_type &val, pt.get_child("kerio_dialplan.dialplan"))
		{
			DialplanExtension dpe(val.second);
			dialplanExtensionList.insert(std::pair<std::string, DialplanExtension > (dpe.telNum, dpe));
		}
	}
	catch (std::exception & e) {
		ast_log(AST_LOG_ERROR, "Configuration error %s\n", e.what());
	}

	ast_verb(3, "Loaded %zu valid extensions.\n", dialplanExtensionList.size());
}

DialPlan::~DialPlan() { }

void DialPlan::printExtensions(const int fd)
{
	ast_cli(fd, "Extensions list\n");
	ast_cli(fd, "---------------\n");
	ast_cli(fd, "Extension number | Extension type\n");

	BOOST_FOREACH(DialplanExtensionList::value_type val, dialplanExtensionList)
	{
		ast_cli(fd, " %15s | %d\n", val.second.telNum.c_str(), val.second.type);
	}
}

/**
 * Find extension for dialing by ext
 *
 * @param extensionNumber [std::string] - extension to look for
 *
 * @return [int] - 1 found, 0 not found
 */
int DialPlan::findDialByExt(const std::string extensionNumber)
{
	DialplanExtensionList::iterator it = dialplanExtensionList.find(extensionNumber);
	if (dialplanExtensionList.end() == it) {
		ast_verb(3, "Searching for extension %s in the dialplan (dialByExt)... %s.\n", extensionNumber.c_str(), "not found");
		return 0; /* not found */
	}

	switch (it->second.type) {
		case 8: /* emergency numbers */
		case 15: /* record audio */
			ast_verb(3, "Searching for extension %s in the dialplan (dialByExt)... %s.\n", extensionNumber.c_str(), "denied");
			return 0;
			break;
		default:
			ast_verb(3, "Searching for extension %s in the dialplan (dialByExt)... %s.\n", extensionNumber.c_str(), "found");
			return 1;
	}
}
